@@ -164,6 +164,9 @@ Options:
   --bpo
          Increment the Debian release number for a backports upload
          to "bookworm-backports"
+  --sloppy
+         Increment the Debian release number for a sloppy backports upload
+         to "bullseye-backports-sloppy"
   --stable
          Increment the Debian release number for a stable upload.
   -l, --local <suffix>
@@ -236,7 +239,7 @@ Options:
   --version
          Display version information
   At most one of -a, -i, -e, -r, -v, -d, -n, --bin-nmu, -q, --qa, -R, -s,
-  --lts, --team, --bpo, --stable, -l (or their long equivalents) may be used.
+  --lts, --team, --bpo, --sloppy, --stable, -l (or their long equivalents) may be used.
   With no options, one of -i or -a is chosen by looking at the release
   specified in the changelog.
 
@@ -363,10 +366,10 @@ my (
     $opt_b, $opt_d, $opt_D, $opt_u, $opt_force_dist
 );
 my (
-    $opt_n,       $opt_bn,   $opt_qa, $opt_R,   $opt_s,
-    $opt_lts,     $opt_team, $opt_U,  $opt_bpo, $opt_stable,
-    $opt_l,       $opt_c,    $opt_m,  $opt_M,   $opt_create,
-    $opt_package, @closes
+    $opt_n,      $opt_bn,      $opt_qa, $opt_R,   $opt_s,
+    $opt_lts,    $opt_team,    $opt_U,  $opt_bpo, $opt_sloppy,
+    $opt_stable, $opt_l,       $opt_c,  $opt_m,   $opt_M,
+    $opt_create, $opt_package, @closes
 );
 my ($opt_news);
 my ($opt_noconf, $opt_empty);
@@ -398,6 +401,7 @@ GetOptions(
     "team"                   => \$opt_team,
     "U|upstream"             => \$opt_U,
     "bpo"                    => \$opt_bpo,
+    "sloppy"                 => \$opt_sloppy,
     "lts"                    => \$opt_lts,
     "stable"                 => \$opt_stable,
     "l|local=s"              => \$opt_l,
@@ -452,7 +456,7 @@ if ($opt_release_heuristic !~ $opt_release_heuristic_re) {
 
 # Only allow at most one non-help option
 fatal
-"Only one of -a, -i, -e, -r, -v, -d, -n/--nmu, --bin-nmu, -q/--qa, -R/--rebuild, -s/--security, --lts, --team, --bpo, --stable, -l/--local is allowed;\ntry $progname --help for more help"
+"Only one of -a, -i, -e, -r, -v, -d, -n/--nmu, --bin-nmu, -q/--qa, -R/--rebuild, -s/--security, --lts, --team, --bpo, --sloppy, --stable, -l/--local is allowed;\ntry $progname --help for more help"
   if ($opt_i ? 1 : 0)
   + ($opt_a ? 1 : 0)
   + ($opt_e ? 1 : 0)
@@ -467,6 +471,7 @@ fatal
   + ($opt_lts ? 1 : 0)
   + ($opt_team ? 1 : 0)
   + ($opt_bpo ? 1 : 0)
+  + ($opt_sloppy ? 1 : 0)
   + ($opt_stable ? 1 : 0)
   + ($opt_l ? 1 : 0) > 1;
 
@@ -504,9 +509,16 @@ if (defined $opt_vendor && $opt_vendor) {
     }
 }
 $vendor ||= 'Debian';
-if ($vendor eq 'Ubuntu'
-    and ($opt_n or $opt_bn or $opt_qa or $opt_bpo or $opt_stable or $opt_lts))
-{
+if (
+    $vendor eq 'Ubuntu'
+    and (  $opt_n
+        or $opt_bn
+        or $opt_qa
+        or $opt_bpo
+        or $opt_sloppy
+        or $opt_stable
+        or $opt_lts)
+) {
     $vendor = 'Debian';
 }
 
@@ -601,11 +613,12 @@ if ($opt_create) {
         || $opt_lts
         || $opt_team
         || $opt_bpo
+        || $opt_sloppy
         || $opt_stable
         || $opt_l
         || $opt_allow_lower) {
         warn
-"$progname warning: ignoring -a/-i/-e/-r/-b/--allow-lower-version/-n/--bin-nmu/-q/--qa/-R/-s/--lts/--team/--bpo/--stable,-l options with --create\n";
+"$progname warning: ignoring -a/-i/-e/-r/-b/--allow-lower-version/-n/--bin-nmu/-q/--qa/-R/-s/--lts/--team/--bpo/--sloppy/--stable,-l options with --create\n";
         $warnings++;
     }
     if ($opt_package && $opt_d) {
@@ -676,8 +689,9 @@ my $EMAIL        = 'EMAIL';
 my $DISTRIBUTION = 'UNRELEASED';
 # when updating the lines below also update the help text, the manpage and the testcases.
 my %dists       = (10, 'buster', 11, 'bullseye', 12, 'bookworm', 13, 'trixie');
-my $lts_dist    = '11';
 my $latest_dist = '12';
+my $old_dist    = $latest_dist - 1;
+my $lts_dist    = '11';
 # dist guessed from backports, SRU, security uploads...
 my $guessed_dist = '';
 my $CHANGES      = '';
@@ -907,6 +921,7 @@ if (
     and !$opt_qa
     and !$opt_R
     and !$opt_bpo
+    and !$opt_sloppy
     and !$opt_bn
     and !$opt_n
     and !$opt_c
@@ -1088,6 +1103,7 @@ if (   !$opt_i
     && !$opt_lts
     && !$opt_team
     && !$opt_bpo
+    && !$opt_sloppy
     && !$opt_stable
     && !$opt_l
     && !$opt_create) {
@@ -1177,6 +1193,7 @@ if ((
         || $opt_lts
         || $opt_team
         || $opt_bpo
+        || $opt_sloppy
         || $opt_stable
         || $opt_l
         || $opt_v
@@ -1298,6 +1315,10 @@ if ((
                 # If it's not already a backport make it so
                 # otherwise we can be safe if we behave like dch -i
                 $end .= "~bpo$latest_dist+1";
+            } elsif ($opt_sloppy and not $start =~ /~bpo[0-9]+\+$/) {
+                # If it's not already a backport make it so
+                # otherwise we can be safe if we behave like dch -i
+                $end .= "~bpo$old_dist+1";
             } elsif ($opt_stable and not $start =~ /\+deb\d+u/) {
                 $end .= "+deb${latest_dist}u1";
             } elsif ($opt_lts and not $start =~ /\+deb\d+u/) {
@@ -1338,7 +1359,11 @@ if ((
 
                 # Attempt to set the distribution for a stable upload correctly
                 # based on the version of the previous upload
-                if ($opt_stable || $opt_bpo || $opt_s || $opt_lts) {
+                if (   $opt_stable
+                    || $opt_bpo
+                    || $opt_sloppy
+                    || $opt_s
+                    || $opt_lts) {
                     my $previous_dist = $start;
                     $previous_dist =~ s/^.*[+~](?:deb|bpo)(\d+)(?:u\+)$/$1/;
                     if (    defined $previous_dist
@@ -1349,6 +1374,9 @@ if ((
                         } elsif ($opt_bpo) {
                             +$guessed_dist
                               = $dists{$previous_dist} . '-backports';
+                        } elsif ($opt_sloppy) {
+                            +$guessed_dist
+                              = $dists{$old_dist} . '-backports-sloppy';
                         } elsif ($opt_stable) {
                             $guessed_dist = $dists{$previous_dist};
                         }
@@ -1380,7 +1408,15 @@ if ((
                     }
                 }
 
-                if (!($opt_qa or $opt_bpo or $opt_stable or $opt_l)) {
+                if (
+                    !(
+                           $opt_qa
+                        or $opt_bpo
+                        or $opt_sloppy
+                        or $opt_stable
+                        or $opt_l
+                    )
+                ) {
                     $useextra = 1;
                 }
             }
@@ -1407,6 +1443,9 @@ if ((
     if ($opt_bpo) {
         $guessed_dist ||= $dists{$latest_dist} . '-backports';
     }
+    if ($opt_sloppy) {
+        $guessed_dist ||= $dists{$old_dist} . '-backports-sloppy';
+    }
     if ($opt_stable) {
         $guessed_dist ||= $dists{$latest_dist};
     }
@@ -1463,6 +1502,9 @@ if ((
         } elsif ($opt_bpo && !$opt_news) {
             print O "  * Rebuild for $guessed_dist.\n";
             $line = 1;
+        } elsif ($opt_sloppy && !$opt_news) {
+            print O "  * Rebuild for $guessed_dist.\n";
+            $line = 1;
         }
         if (@closes_text or $TEXT or $EMPTY_TEXT) {
             foreach (@closes_text) { format_line($_, 1); }
